from glob2 import glob
import re

def epr_recursive_import(path):
    paths = glob(path + '/**/*.py')

    for path in paths:
        with open(path, 'r+') as f:
            content = f.read()
            match = re.search(r'\bepr\(', content)
            if match:
                f.seek(0, 0)
                f.write('from epr import epr\n' + content)



from termcolor import colored
import json

def epr(i, color='black', attrs=[]):
    if isinstance(i, str):
        print(colored(i, color, attrs=attrs))
    else:
        print(colored(json.dumps(i), color, attrs=attrs))
    return i



from setuptools import setup

setup(
        name='epr',
        version='0.01',
        author='Luke Avery',
        author_email='cogmob@gmail.com',
        url='https://github.com/Cogmob/epr',
        description=('Tool for quickly adding debugging output'),
        packages=[
            'epr'
        ],
        long_description=open('README.rst', 'r').read()
)
